@@ -4,8 +4,7 @@ from jaxmd_tools._src.utils import (
     kT_inv,
     save_pickle,
     load_pickle,
-    is_notebook,
     log,
 )
 
-__all__ = ["is_nonempty_array", "kT", "kT_inv", "save_pickle", "load_pickle", "is_notebook", "log"]
+__all__ = ["is_nonempty_array", "kT", "kT_inv", "save_pickle", "load_pickle", "log"]
